@@ -1,6 +1,6 @@
 package Yahoo::Search;
 BEGIN {
-  $Yahoo::Search::VERSION = '1.11.1';
+  $Yahoo::Search::VERSION = '1.11.2';
 }
 use strict;
 use Carp;
@@ -1103,7 +1103,7 @@ Yahoo::Search - Perl interface to the Yahoo! Search public API.
 
 =head1 VERSION
 
-version 1.11.1
+version 1.11.2
 
 The following search spaces are supported:
 
@@ -2227,4 +2227,12 @@ perldoc for LWP for more.
 
 Jeffrey Friedl (jfriedl@yahoo.com)
 
+Jeffrey placed the 1.10.13 code in the public domain (or, technically, the
+http://creativecommons.org/publicdomain/zero/1.0/ licence) on June 11th 2010.
+Tim Bunce (Tim.Bunce@pobox.com) currently maintains the code, though with very
+little spare much time. He's very happy for someone else to help out.
+
+Please use https://rt.cpan.org/Dist/Display.html?Queue=Yahoo-Search to
+submit bug reports.
+
 =cut
\ No newline at end of file
